@@ -22,8 +22,10 @@
 #                                                                              #
 # ##############################################################################
 
+from os.path import basename
 import github.GithubObject
 import github.GitAuthor
+import github.GitReleaseAsset
 
 
 class GitRelease(github.GithubObject.CompletableGithubObject):
@@ -34,6 +36,14 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
     def __repr__(self):
         return self.get__repr__({"title": self._title.value})
 
+    @property
+    def id(self):
+        """
+        :type: integer
+        """
+        self._completeIfNotSet(self._id)
+        return self._id.value
+
     @property
     def body(self):
         """
@@ -66,6 +76,22 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         self._completeIfNotSet(self._author)
         return self._author.value
 
+    @property
+    def created_at(self):
+        """
+        :type: datetime.datetime
+        """
+        self._completeIfNotSet(self._created_at)
+        return self._created_at.value
+
+    @property
+    def published_at(self):
+        """
+        :type: datetime.datetime
+        """
+        self._completeIfNotSet(self._published_at)
+        return self._published_at.value
+
     @property
     def url(self):
         """
@@ -116,7 +142,36 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         )
         return github.GitRelease.GitRelease(self._requester, headers, data, completed=True)
 
+    def upload_asset(self, path, label="", content_type=""):
+        assert isinstance(path, str), path
+        assert isinstance(label, str), label
+
+        post_parameters = {
+            "name": basename(path),
+            "label": label
+        }
+        headers = {}
+        if len(content_type) > 0:
+            headers["Content-Type"] = content_type
+        resp_headers, data = self._requester.requestBlobAndCheck(
+            "POST",
+            self.upload_url.split("{?")[0],
+            parameters=post_parameters,
+            headers=headers,
+            input=path
+        )
+        return github.GitReleaseAsset.GitReleaseAsset(self._requester, resp_headers, data, completed=True)
+
+    def get_assets(self):
+        return github.PaginatedList.PaginatedList(
+            github.GitReleaseAsset.GitReleaseAsset,
+            self._requester,
+            self.url + "/assets",
+            None
+        )
+
     def _initAttributes(self):
+        self._id = github.GithubObject.NotSet
         self._body = github.GithubObject.NotSet
         self._title = github.GithubObject.NotSet
         self._tag_name = github.GithubObject.NotSet
@@ -124,8 +179,12 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
         self._url = github.GithubObject.NotSet
         self._upload_url = github.GithubObject.NotSet
         self._html_url = github.GithubObject.NotSet
+        self._created_at = github.GithubObject.NotSet
+        self._published_at = github.GithubObject.NotSet
 
     def _useAttributes(self, attributes):
+        if "id" in attributes:
+            self._id = self._makeIntAttribute(attributes["id"])
         if "body" in attributes:
             self._body = self._makeStringAttribute(attributes["body"])
         if "name" in attributes:
@@ -140,3 +199,7 @@ class GitRelease(github.GithubObject.CompletableGithubObject):
             self._upload_url = self._makeStringAttribute(attributes["upload_url"])
         if "html_url" in attributes:
             self._html_url = self._makeStringAttribute(attributes["html_url"])
+        if "created_at" in attributes:
+            self._created_at = self._makeDatetimeAttribute(attributes["created_at"])
+        if "published_at" in attributes:
+            self._published_at = self._makeDatetimeAttribute(attributes["published_at"])
