@@ -33,26 +33,23 @@
 #                                                                              #
 # ##############################################################################
 
-import logging
-import http.client
 import base64
+import http.client
+import json
+import logging
+import mimetypes
+import os
+import re
+import sys
 import urllib.request, urllib.parse, urllib.error
 import urllib.parse
-import sys
+from io import IOBase
+
 from . import Consts
-import re
-import os
-
-atLeastPython26 = sys.hexversion >= 0x02060000
-atLeastPython3 = sys.hexversion >= 0x03000000
-
-if atLeastPython26:
-    import json
-else:  # pragma no cover (Covered by all tests with Python 2.5)
-    import simplejson as json  # pragma no cover (Covered by all tests with Python 2.5)
-
 from . import GithubException
 
+atLeastPython3 = sys.hexversion >= 0x03000000
+
 
 class Requester:
     __httpConnectionClass = http.client.HTTPConnection
@@ -87,12 +84,12 @@ class Requester:
     ON_CHECK_ME = None
 
     def NEW_DEBUG_FRAME(self, requestHeader):
-        '''
+        """
         Initialize a debug frame with requestHeader
         Frame count is updated and will be attached to respond header
         The structure of a frame: [requestHeader, statusCode, responseHeader, raw_data]
         Some of them may be None
-        '''
+        """
         if self.DEBUG_FLAG:  # pragma no branch (Flag always set in tests)
             new_frame = [requestHeader, None, None, None]
             if self._frameCount < self.DEBUG_FRAME_BUFFER_SIZE - 1:  # pragma no branch (Should be covered)
@@ -174,6 +171,11 @@ class Requester:
     def requestMultipartAndCheck(self, verb, url, parameters=None, headers=None, input=None):
         return self.__check(*self.requestMultipart(verb, url, parameters, headers, input))
 
+    def requestBlobAndCheck(self, verb, url, parameters=None, headers=None, input=None):
+        o = urllib.parse.urlparse(url)
+        self.__hostname = o.hostname
+        return self.__check(*self.requestBlob(verb, url, parameters, headers, input))
+
     def __check(self, status, responseHeaders, output):
         output = self.__structuredFromJson(output)
         if status >= 400:
@@ -228,6 +230,20 @@ class Requester:
 
         return self.__requestEncode(None, verb, url, parameters, headers, input, encode)
 
+    def requestBlob(self, verb, url, parameters={}, headers={}, input=None):
+        def encode(local_path):
+            if "Content-Type" in headers:
+                mime_type = headers["Content-Type"]
+            else:
+                guessed_type = mimetypes.guess_type(input)
+                mime_type = guessed_type[0] if guessed_type[0] is not None else "application/octet-stream"
+            f = open(local_path, 'rb')
+            return mime_type, f
+
+        if input:
+            headers["Content-Length"] = os.path.getsize(input)
+        return self.__requestEncode(None, verb, url, parameters, headers, input, encode)
+
     def __requestEncode(self, cnx, verb, url, parameters, requestHeaders, input, encode):
         assert verb in ["HEAD", "GET", "POST", "PATCH", "PUT", "DELETE"]
         if parameters is None:
@@ -243,7 +259,7 @@ class Requester:
         url = self.__makeAbsoluteUrl(url)
         url = self.__addParametersToUrl(url, parameters)
 
-        encoded_input = "null"
+        encoded_input = None
         if input is not None:
             requestHeaders["Content-Type"], encoded_input = encode(input)
 
@@ -283,6 +299,9 @@ class Requester:
         output = response.read()
 
         cnx.close()
+        if input:
+            if isinstance(input, IOBase):
+                input.close()
 
         self.__log(verb, url, requestHeaders, input, status, responseHeaders, output)
 
@@ -305,8 +324,8 @@ class Requester:
             url = self.__prefix + url
         else:
             o = urllib.parse.urlparse(url)
-            assert o.hostname == self.__hostname
-            assert o.path.startswith(self.__prefix)
+            assert o.hostname in [self.__hostname, "uploads.github.com"], o.hostname
+            assert o.path.startswith((self.__prefix, "/api/uploads"))
             assert o.port == self.__port
             url = o.path
             if o.query != "":
@@ -323,8 +342,7 @@ class Requester:
         kwds = {}
         if not atLeastPython3:  # pragma no branch (Branch useful only with Python 3)
             kwds["strict"] = True  # Useless in Python3, would generate a deprecation warning
-        if atLeastPython26:  # pragma no branch (Branch useful only with Python 2.5)
-            kwds["timeout"] = self.__timeout  # Did not exist before Python2.6
+        kwds["timeout"] = self.__timeout
 
         ##
         ## Connect through a proxy server with authentication, if http_proxy
