@@ -25,22 +25,17 @@
 #                                                                              #
 # ##############################################################################
 
+import http.client
+import json
 import os
 import sys
-import unittest
-import http.client
 import traceback
+import unittest
 
 import github
 
-atLeastPython26 = sys.hexversion >= 0x02060000
+python2 = sys.hexversion < 0x03000000
 atLeastPython3 = sys.hexversion >= 0x03000000
-atMostPython32 = sys.hexversion < 0x03030000
-
-if atLeastPython26:
-    import json
-else:  # pragma no cover (Covered by all tests with Python 2.5)
-    import simplejson as json  # pragma no cover (Covered by all tests with Python 2.5)
 
 
 def readLine(file):
@@ -150,12 +145,16 @@ class ReplayingConnection:
         self.__testCase.assertEqual(self.__splitUrl(url), self.__splitUrl(readLine(self.__file)))
         self.__testCase.assertEqual(headers, eval(readLine(self.__file)))
         expectedInput = readLine(self.__file)
-        if input.startswith("{"):
-            self.__testCase.assertEqual(json.loads(input.replace('\n', '').replace('\r', '')), json.loads(expectedInput))
-        elif atMostPython32:  # @todo Test in all cases, including Python 3.3
-            # In Python 3.3, dicts are not output in the same order as in Python 2.5 -> 3.2.
-            # So, form-data encoding is not deterministic and is difficult to test.
-            self.__testCase.assertEqual(input.replace('\n', '').replace('\r', ''), expectedInput)
+        if isinstance(input, str):
+            if input.startswith("{"):
+                self.__testCase.assertEqual(json.loads(input.replace('\n', '').replace('\r', '')), json.loads(expectedInput))
+            elif python2:  # @todo Test in all cases, including Python 3.4+
+                # In Python 3.4+, dicts are not output in the same order as in Python 2.7.
+                # So, form-data encoding is not deterministic and is difficult to test.
+                self.__testCase.assertEqual(input.replace('\n', '').replace('\r', ''), expectedInput)
+        else:
+            # for non-string input (e.g. upload asset), let it pass.
+            pass
 
     def __splitUrl(self, url):
         splitedUrl = url.split("?")
